## neptune-tensorboard 1.0.0.pre0

### Changes
- Update integration to work with latest `neptune` client and update the meta-data logging structure ([#51](https://github.com/neptune-ai/neptune-tensorboard/pull/51))

## neptune-tensorboard 0.5.3

### Changes
- Moved `neptune_tensorboard` and `neptune_tensorboard_plugin` packages to `src` directory ([#47](https://github.com/neptune-ai/neptune-tensorboard/pull/47))
